import 'package:collection/collection.dart';
import 'package:elevarm_ui/elevarm_ui.dart';
import 'package:elevarm_ui/src/styles/styles.dart';
import 'package:flutter/material.dart';

/// Elevarm UI's Outline Tab Bar component widget.
class ElevarmTabBar extends StatelessWidget {
  /// Currently active index.
  final int activeIndex;

  /// Tabs' label.
  final List<String> labels;

  /// Callback when a tab is clicked.
  final void Function(int index) onChange;

  const ElevarmTabBar({
    super.key,
    required this.labels,
    required this.activeIndex,
    required this.onChange,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        color: ElevarmColors.neutral50,
        borderRadius: BorderRadius.circular(8.0),
      ),
      child: Padding(
        padding: const EdgeInsets.symmetric(
          vertical: 4.0,
        ),
        child: Row(
          children: labels.mapIndexed<Widget>(
            (index, label) {
              if (index == activeIndex) {
                return _buildActiveTab(
                  label: label,
                  onPressed: () {
                    onChange(index);
                  },
                );
              }
              return _buildInactiveTab(
                label: label,
                onPressed: () {
                  onChange(index);
                },
              );
            },
          ).toList(),
        ),
      ),
    );
  }

  /// Build active tab widget.
  Widget _buildActiveTab({
    required String label,
    required VoidCallback onPressed,
  }) {
    return Expanded(
      child: Padding(
        padding: const EdgeInsets.symmetric(
          horizontal: 4.0,
        ),
        child: Container(
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(6.0),
            boxShadow: ElevarmBoxShadow.sm,
          ),
          child: Material(
            color: ElevarmColors.white,
            borderRadius: BorderRadius.circular(6.0),
            child: InkWell(
              onTap: onPressed,
              borderRadius: BorderRadius.circular(6.0),
              child: Container(
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(6.0),
                ),
                padding: const EdgeInsets.symmetric(vertical: 8.0),
                child: Text(
                  label,
                  style: LibraryTextStyles.interSmSemiboldNeutral,
                  textAlign: TextAlign.center,
                ),
              ),
            ),
          ),
        ),
      ),
    );
  }

  /// Build inactive tab widget.
  Widget _buildInactiveTab({
    required String label,
    required VoidCallback onPressed,
  }) {
    return Expanded(
      child: Material(
        color: Colors.transparent,
        borderRadius: BorderRadius.circular(6.0),
        child: InkWell(
          onTap: onPressed,
          borderRadius: BorderRadius.circular(6.0),
          child: Container(
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(6.0),
            ),
            padding: const EdgeInsets.symmetric(vertical: 8.0),
            child: Text(
              label,
              style: LibraryTextStyles.interSmSemiboldNeutral300,
              textAlign: TextAlign.center,
            ),
          ),
        ),
      ),
    );
  }
}
